@@ -201,34 +201,65 @@ class OpenEuler():
             return core_src_list
 
     def get_rpm_name_from_full_name(self, rpm):
-        rpm_clean = rpm.strip()
+        if not rpm:
+            log.warning("Empty RPM name input")
+            return None
 
+            # ===================== 步骤1：基础清理 =====================
+        rpm_clean = rpm.strip()
         # 移除结尾的 .rpm 后缀（忽略大小写）
         rpm_clean = re.sub(r"\.rpm$", "", rpm_clean, flags=re.IGNORECASE)
-        # 移除结尾的架构后缀（x86_64/aarch64等，解决.oe2403sp2.x86_64的层级干扰）
+        # 移除结尾的架构后缀（x86_64/aarch64等）
         arch_pattern = r"\.(x86_64|aarch64|arm64|i386|noarch|ppc64le|s390x)$"
         rpm_clean = re.sub(arch_pattern, "", rpm_clean, flags=re.IGNORECASE)
+        # 移除末尾的空白/分隔符
+        rpm_clean = rpm_clean.rstrip("-_.")
 
-        # 步骤2：核心正则匹配（精准提取包名，适配v前缀/发行版标识）
-        # 正则逻辑：
-        # ^(.+?)-        匹配包名（非贪婪），直到最后一个"-"
-        # (?=            正向预查（不捕获），确保后面是版本段：
-        #   (v\d|svn|rc|beta|alpha|dev|release|\d)  版本起始标识（v2/svn17115/1.0等）
-        #   \w*           版本中间字符（数字/字母/下划线等）
-        #   (\.|-|oe|el|centos|fc|sp)              版本中的分隔符/发行版标识（.oe2403sp2/-el8等）
-        #   .*            版本剩余部分（兼容多级发行版，如oe2403sp2）
-        # )
-        pkg_pattern = r"^(.+?)-(?=(v\d|svn|rc|beta|alpha|dev|release|\d)\w*(\.|-|oe|el|centos|fc|sp).*$)"
-        match = re.match(pkg_pattern, rpm_clean, re.IGNORECASE)
+        # ===================== 步骤2：定位版本段边界（原有逻辑） =====================
+        # 发行版标识（可按需扩展）
+        dist_identifiers = ["oe", "el", "centos", "fc", "sles", "debian", "ubuntu"]
+        dist_pattern = re.compile(rf"({'|'.join(dist_identifiers)})\d+", re.IGNORECASE)
+        # 版本段核心特征（纯数字/版本标识开头）
+        version_core_pattern = re.compile(r"^\d+(\.|-|_)|^v\d+|^svn\d+|^rc\d+|^beta\d+|^alpha\d+", re.IGNORECASE)
 
-        # 步骤3：结果处理
-        if match:
-            pkg_name = match.group(1)
-            log.debug(f"Extracted RPM name: {pkg_name} | Original: {rpm} | Cleaned: {rpm_clean}")
-            return pkg_name
+        # 从后往前拆分，定位版本段起始位置
+        parts = rpm_clean.split("-")
+        version_start_idx = None
+        for i in reversed(range(len(parts))):
+            part = parts[i]
+            # 条件1：包含发行版标识（如 oe2403sp1、el8）→ 版本段起始
+            if dist_pattern.search(part):
+                version_start_idx = i
+                break
+            # 条件2：是纯版本核心（如 1.8.0.432、v3.22.0）→ 版本段起始
+            if version_core_pattern.match(part) or (part.replace(".", "").isdigit() and len(part) > 1):
+                version_start_idx = i
+                break
+
+        # 拼接初步包名（兜底逻辑）
+        if version_start_idx is not None and version_start_idx > 0:
+            pkg_name = "-".join(parts[:version_start_idx]).strip("-")
         else:
-            log.warning(f"RPM name {rpm} does not match pattern (cleaned: {rpm_clean})")
-            return None
+            log.warning(f"No valid version segment found for RPM: {rpm} (cleaned: {rpm_clean})")
+            pkg_name = rpm_clean
+
+        # ===================== 步骤3：核心优化：移除包名内的版本号 =====================
+        # 版本号正则：匹配 数字.数字.数字 或 纯数字段（如 1.3.261.0、22.0、11）
+        pkg_version_pattern = re.compile(
+            r"-(\d+(\.\d+)+|\d+)$",  # 匹配末尾的版本号（如 -1.3.261.0、-1.22.0、-11）
+            flags=re.IGNORECASE
+        )
+        # 循环清理：确保移除所有层级的版本号（如 java-1.8.0-openjdk → java-openjdk）
+        while pkg_version_pattern.search(pkg_name):
+            pkg_name = pkg_version_pattern.sub("", pkg_name)
+
+        # 最终校验：避免空包名
+        if not pkg_name:
+            log.warning(f"Extracted empty pkg name for RPM: {rpm} (cleaned: {rpm_clean})")
+            pkg_name = rpm_clean
+
+        log.debug(f"Extracted RPM name: {pkg_name} | Original: {rpm} | Cleaned: {rpm_clean}")
+        return pkg_name
 
     def get_openEuler_pkgs(
             self, os_version: str, os_arch: str, scope: str
@@ -247,11 +278,15 @@ class OpenEuler():
             RuntimeError: 网络请求失败（如超时、404、500 等）
             ValueError: 页面解析失败（未找到任何 .rpm 包）
         """
-        base_url_template = "https://dl-cdn.openeuler.openatom.cn/openEuler-{os_version}/{scope}/{os_arch}/Packages/"
+        base_url_template = "https://fast-mirror.isrc.ac.cn/openeuler/openEuler-{os_version}/{scope}/{os_arch}/Packages/"
         timeout = 15
         headers = {
             "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/120.0.0.0 Safari/537.36",
-            "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8"
+            "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.7",
+            "Accept-Encoding": "gzip, deflate, br",
+            "Accept-Language": "zh-CN,zh;q=0.9,en;q=0.8",
+            "Referer": "https://www.openeuler.org/",
+            "Connection": "keep-alive",
         }
 
         target_url = base_url_template.format(os_version=os_version, os_arch=os_arch,scope= scope)
@@ -286,13 +321,13 @@ class OpenEuler():
         if not pkg_links:
             log.error(f"页面解析失败！URL: {target_url}, 未找到任何 .rpm 包")
             return
-
         for link in pkg_links:
             full_pkg_name = link.get("href", "").strip()
             if full_pkg_name:  # 过滤空字符串
                 pkg_name=self.get_rpm_name_from_full_name(full_pkg_name)
                 yield pkg_name,full_pkg_name
 
+
     def get_openEuler_core_rpm_list(self,os_version,os_arch):
         core_src_list=self.get_core_src_list()
         core_rpm_list=[]
@@ -307,6 +342,8 @@ class OpenEuler():
         for rpm_name, _ in self.get_openEuler_pkgs(os_version, os_arch, "everything"):
             if rpm_name not in all_rpm_list:
                 all_rpm_list.append(rpm_name)
+            else:
+                log.error(f"重复的包名称：{rpm_name}")
         return all_rpm_list
 
     def get_openEuler_epol_rpm_list(self, os_version: str, os_arch: str):
@@ -328,6 +365,8 @@ class OpenEuler():
         for rpm_name, _ in self.get_openEuler_pkgs(os_version, os_arch, "OS"):
             if rpm_name not in all_rpm_list:
                 all_rpm_list.append(rpm_name)
+            else:
+                print(f"重复的包名称：{rpm_name}")
         return all_rpm_list
 
 
@@ -419,7 +458,7 @@ class OpenEuler():
 
 if __name__ == "__main__":
     # 初始化获取器
-    # oe = OpenEuler()
+    oe = OpenEuler()
     # rs = oe.get_openEuler_os_rpm2src("24.03-LTS-SP1", "x86_64")
     # print(len(rs.keys()))
     # rs = oe.get_openEuler_update_rpm2src("24.03-LTS-SP1", "x86_64")
@@ -434,14 +473,16 @@ if __name__ == "__main__":
     # print(rpm)
     # rpm=oe.get_rpm_name_from_full_name("nodejs-lodash-valuesin-3.10.1-1.oe2403sp2.noarch.rpm")
     # print(rpm)
-    # rs=oe.get_openEuler_everything_rpm_list("24.03-LTS-SP2", "x86_64")
+    rs=oe.get_openEuler_everything_rpm_list("24.03-LTS-SP1", "x86_64")
     # print(f"everything {len(rs)} pkgs")
-    # rs=oe.get_openEuler_epol_rpm_list("24.03-LTS-SP2", "x86_64")
+    # rs=oe.get_openEuler_epol_rpm_list("24.03-LTS-SP1", "x86_64")
     # print(f"epol {len(rs)} pkgs")
-    # rs=oe.get_openEuler_update_rpm_list("24.03-LTS-SP2", "x86_64")
+    # rs=oe.get_openEuler_update_rpm_list("24.03-LTS-SP1", "x86_64")
     # print(f"update {len(rs)} pkgs")
-    # rs=oe.get_openEuler_os_rpm_list("24.03-LTS-SP2", "x86_64")
-    # print(f"os {len(rs)} pkgs")
+    # rs=oe.get_openEuler_os_rpm_list("24.03-LTS-SP1", "x86_64")
+    # for rpm in rs:
+    #     print(f"{rpm}")
+    print(f"os {len(rs)} pkgs")
     # rs=oe.get_openEuler_all_rpm_list("24.03-LTS-SP2", "x86_64")
     # print(f"total {len(rs)} pkgs")
 
